package App::Git::Perl;

our $VERSION = '0.1.8';

=head1 NAME

App::Git::Perl - adds custom git command "git perl" to make it easier to monitor latest changes in perl modules, and make you collaborate faster.

=head1 DESCRIPTION

This is a stub module, see L<git-perl> for details of the app.

=head1 AUTHOR

Nedzad Hrnjica

=head1 LICENSE

 Perl License (perl)

=cut

1;
